@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -19,7 +19,8 @@
 
 #include "syntaxhighlighterbase.h"
 #include <QRegularExpressionMatch>
-#include <QDebug>
+#include "kpimtextedit_debug.h"
+#include "helper_p.h"
 using namespace KPIMTextEdit;
 SyntaxHighlighterBase::SyntaxHighlighterBase(QTextDocument *doc)
     : QSyntaxHighlighter(doc)
@@ -34,11 +35,11 @@ SyntaxHighlighterBase::~SyntaxHighlighterBase()
 
 void SyntaxHighlighterBase::highlightBlock(const QString &text)
 {
-    Q_FOREACH (const Rule &rule, m_rules) {
+    for (const Rule &rule : qAsConst(m_rules)) {
         const QRegularExpression expression(rule.pattern);
         if (!expression.isValid()) {
             const QString errorString = expression.errorString();
-            qDebug() << "expression is invalid, pattern:" << rule.pattern << " error :" << errorString;
+            qCDebug(KPIMTEXTEDIT_LOG) << "expression is invalid, pattern:" << rule.pattern << " error :" << errorString;
         }
         QRegularExpressionMatch match = expression.match(text);
 
